"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var core_1 = require("@angular/core");
var http_1 = require("@angular/common/http");
var Observable_1 = require("rxjs/Observable");
var error_1 = require("../data/error");
var locator_service_1 = require("./locator.service");
var message_service_1 = require("./message.service");
var general_utils_service_1 = require("./general-utils.service");
var HttpUtilsService = (function () {
    function HttpUtilsService(http, messageService, generalUtils) {
        this.http = http;
        this.messageService = messageService;
        this.generalUtils = generalUtils;
        //@Inject("API_URL") public apiUrl: string Falla con AOT
        var injector = locator_service_1.LocatorService.injector;
        console.log("API_URL :" + HttpUtilsService.API_URL);
        console.log("HttpUtilsSerive creado con API Url:" + this.apiUrl());
    }
    HttpUtilsService.prototype.handleError = function (error) {
        this.generalUtils.stopLoading();
        var customError = HttpUtilsService.getCustomError(error);
        this.messageService.sendError(customError);
        return Observable_1.Observable.throw(customError);
    };
    HttpUtilsService.getCustomError = function (error) {
        var lastUrlAcceded = error.url;
        var innerError = error.error; //intentamos parsear error.error para ver si nos ha llegado un pete controlado del servidor
        var customError;
        if (innerError && (innerError['notificacion'] || innerError['trazaError'])) {
            //el error es controlado del servidor
            customError = innerError;
        }
        else {
            //el error es un problema de comunicaciones o del propio cliente Angular
            if (error.status) {
                //caso jetty o error controlado del servidor
                switch (error.status) {
                    case 401: {
                        console.log("Error de autenticación");
                        customError = new error_1.Error(lastUrlAcceded, "Error d'autenticació", "Error de autenticación", undefined, true, "Torni a introduir el seu login i contrassenya");
                        HttpUtilsService.reloadPage();
                        break;
                    }
                    case 403: {
                        console.log("status 403");
                        customError = new error_1.Error(lastUrlAcceded, "Acces no autoritzat", "Acceso no autorizado", undefined, true, "No està autoritzat per a realitzar aquesta funció");
                        break;
                    }
                    case 404: {
                        console.log("status 404");
                        customError = new error_1.Error(lastUrlAcceded, "Error d'acces", "Error de acceso", undefined, true, "No existeix l'element al que s'intenta accedir");
                        break;
                    }
                    case 504: {
                        console.log("status:" + error.status);
                        customError = new error_1.Error(lastUrlAcceded, "Error de connexió", "Error de conexión", undefined, true, "No s'ha pogut establir la connexió amb el servidor");
                        break;
                    }
                    default: {
                        console.log("status:" + error.status);
                        customError = new error_1.Error(lastUrlAcceded, "Error desconegut", "Error desconocido", undefined, true, "No s'ha pogut descobrir el motiu de l'error");
                    }
                }
            }
            else {
                customError = new error_1.Error(lastUrlAcceded, error.message, error.error);
            }
        }
        return customError;
    };
    ;
    // TODO customizar por proyecto
    // TODO customizar por proyecto
    HttpUtilsService.reloadPage = 
    // TODO customizar por proyecto
    function () {
        var currentUrl = window.location.href;
        console.log("current url " + currentUrl);
        var index = currentUrl.lastIndexOf('bitcitafront');
        var newUrl;
        if (index != -1) {
            newUrl = currentUrl.substring(0, currentUrl.lastIndexOf('bitcitafront') + 12);
        }
        else {
            newUrl = currentUrl;
        }
        console.log("new url " + newUrl);
        window.location.href = newUrl;
    };
    HttpUtilsService.prototype.getHttpPost = function (url, hqlRequest, emptyResponse) {
        var _this = this;
        if (emptyResponse === void 0) { emptyResponse = false; }
        console.log("calling url server via POST:" + this.apiUrl() + url);
        this.generalUtils.startLoading();
        var body = JSON.stringify(hqlRequest);
        var headers = new http_1.HttpHeaders().set('Content-Type', 'application/json');
        var vResponseType = emptyResponse ? 'text' : 'json';
        return this.http.post(this.apiUrl() + url, body, { headers: headers, responseType: vResponseType })
            .do(function (res) { return _this.generalUtils.stopLoading(); }, function (error) { return _this.handleError(error); });
    };
    HttpUtilsService.prototype.getHttpPut = function (url, hqlRequest) {
        var _this = this;
        console.log("calling url server via PUT:" + this.apiUrl() + url);
        this.generalUtils.startLoading();
        var body = JSON.stringify(hqlRequest);
        var headers = new http_1.HttpHeaders().set('Content-Type', 'application/json');
        return this.http.put(this.apiUrl() + url, body, { headers: headers })
            .do(function (res) { return _this.generalUtils.stopLoading(); }, function (error) { return _this.handleError(error); });
    };
    HttpUtilsService.prototype.getHttpDelete = function (url) {
        var _this = this;
        console.log("calling url server via DELETE:" + this.apiUrl() + url);
        this.generalUtils.startLoading();
        var headers = new http_1.HttpHeaders().set('Content-Type', 'application/json');
        return this.http.delete(this.apiUrl() + url, {
            headers: headers,
            responseType: 'text'
        })
            .do(function (res) { return _this.generalUtils.stopLoading(); }, function (error) { return _this.handleError(error); });
    };
    HttpUtilsService.prototype.getHttpGet = function (url) {
        var _this = this;
        console.log("calling url server via GET:" + this.apiUrl() + url);
        this.generalUtils.startLoading();
        return this.http.get(this.apiUrl() + url)
            .do(function (res) { return _this.generalUtils.stopLoading(); }, function (error) { return _this.handleError(error); });
    };
    HttpUtilsService.prototype.apiUrl = function () {
        return HttpUtilsService.API_URL;
    };
    HttpUtilsService.API_URL = "http://localhost:8081/api/services/";
    HttpUtilsService.decorators = [
        { type: core_1.Injectable },
    ];
    /** @nocollapse */
    HttpUtilsService.ctorParameters = function () { return [
        { type: http_1.HttpClient, },
        { type: message_service_1.MessageService, },
        { type: general_utils_service_1.GeneralUtils, },
    ]; };
    return HttpUtilsService;
}());
exports.HttpUtilsService = HttpUtilsService;
exports.httpUtilsServiceInjectables = [
    { provide: HttpUtilsService,
        useClass: HttpUtilsService
    } /*,
        {   provide: "API_URL",
            useValue: API_URL
        }*/
];
//# sourceMappingURL=http-utils.service.js.map